https://realpython.com/python-pipx/
https://realpython.com/tic-tac-toe-ai-python/
https://python-poetry.org/
https://realpython.com/python-wheels/
https://packaging.python.org/en/latest/guides/using-testpypi/